@@ -1,8 +1,8 @@
 // Copyright 2019-2022 ChainSafe Systems
 // SPDX-License-Identifier: Apache-2.0, MIT
 
-use fvm_ipld_blockstore::Blockstore;
-use fvm_ipld_encoding::RawBytes;
+use fvm_shared::blockstore::Blockstore;
+use fvm_shared::encoding::RawBytes;
 use fvm_shared::MethodNum;
 
 use crate::{ActorError, Runtime};
@@ -17,6 +17,8 @@ pub trait ActorCode {
         params: &RawBytes,
     ) -> Result<RawBytes, ActorError>
     where
-        BS: Blockstore,
+        // TODO: remove the clone requirement on the blockstore when we fix "replica update" to not
+        // hold onto state between transactions.
+        BS: Blockstore + Clone,
         RT: Runtime<BS>;
 }
